@@ -30,24 +30,28 @@
 #include <QtCore/QTextCodec>
 #include <QtGui/QLinearGradient>
 #include <QtGui/QRadialGradient>
+#include <QtGui/QIcon>
 #include <QtCore/QTimer>
-
+#include <QCompleter>
+#include <QFileSystemModel>
+#include <QtCore/QUrl>
+#include <QDebug>
 // KDE
 #include <kdeversion.h>
-#if KDE_IS_VERSION(4, 9, 1)
 #include <KCodecAction>
-#else
-#include <kcodecaction.h>
-#endif
 
 #include <KFontDialog>
-#include <KIcon>
 #include <KIconDialog>
 #include <KFileDialog>
 #include <KUrlCompletion>
 #include <KWindowSystem>
 #include <KTextEdit>
 #include <KMessageBox>
+#include <KLocalizedString>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 // Konsole
 #include "ColorScheme.h"
@@ -65,22 +69,32 @@
 using namespace Konsole;
 
 EditProfileDialog::EditProfileDialog(QWidget* aParent)
-    : KDialog(aParent)
+    : QDialog(aParent)
     , _delayedPreviewTimer(new QTimer(this))
     , _colorDialog(0)
 {
-    setCaption(i18n("Edit Profile"));
-    setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Apply);
+    setWindowTitle(i18n("Edit Profile"));
+    mButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::Apply);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = mButtonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(mButtonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(mButtonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
     // disable the apply button , since no modification has been made
-    enableButtonApply(false);
+    mButtonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
 
-    connect(this, SIGNAL(applyClicked()), this, SLOT(save()));
+    connect(mButtonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &Konsole::EditProfileDialog::save);
 
-    connect(_delayedPreviewTimer, SIGNAL(timeout()), this, SLOT(delayedPreviewActivate()));
+    connect(_delayedPreviewTimer, &QTimer::timeout, this, &Konsole::EditProfileDialog::delayedPreviewActivate);
 
     _ui = new Ui::EditProfileDialog();
-    _ui->setupUi(mainWidget());
+    _ui->setupUi(mainWidget);
+    mainLayout->addWidget(mButtonBox);
 
     // there are various setupXYZPage() methods to load the items
     // for each page and update their states to match the profile
@@ -93,8 +107,7 @@ EditProfileDialog::EditProfileDialog(QWidget* aParent)
     // not been updated since the last profile change and will need
     // to be refreshed when the user switches to them
     _pageNeedsUpdate.resize(_ui->tabWidget->count());
-    connect(_ui->tabWidget, SIGNAL(currentChanged(int)), this,
-            SLOT(preparePage(int)));
+    connect(_ui->tabWidget, &QTabWidget::currentChanged, this, &Konsole::EditProfileDialog::preparePage);
 
     createTempProfile();
 }
@@ -119,12 +132,12 @@ void EditProfileDialog::save()
 
     createTempProfile();
 
-    enableButtonApply(false);
+    mButtonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
 }
 void EditProfileDialog::reject()
 {
     unpreviewAll();
-    KDialog::reject();
+    QDialog::reject();
 }
 void EditProfileDialog::accept()
 {
@@ -141,7 +154,7 @@ void EditProfileDialog::accept()
     }
     save();
     unpreviewAll();
-    KDialog::accept();
+    QDialog::accept();
 }
 QString EditProfileDialog::groupProfileNames(const ProfileGroup::Ptr group, int maxLength)
 {
@@ -166,12 +179,12 @@ void EditProfileDialog::updateCaption(const Profile::Ptr profile)
     ProfileGroup::Ptr group = profile->asGroup();
     if (group && group->profiles().count() > 1) {
         QString caption = groupProfileNames(group, MAX_GROUP_CAPTION_LENGTH);
-        setCaption(i18np("Editing profile: %2",
+        setWindowTitle(i18np("Editing profile: %2",
                          "Editing %1 profiles: %2",
                          group->profiles().count(),
                          caption));
     } else {
-        setCaption(i18n("Edit Profile \"%1\"", profile->name()));
+        setWindowTitle(i18n("Edit Profile \"%1\"", profile->name()));
     }
 }
 void EditProfileDialog::setProfile(Profile::Ptr profile)
@@ -244,7 +257,7 @@ void EditProfileDialog::setupGeneralPage(const Profile::Ptr profile)
         ProfileGroup::Ptr group = profile->asGroup();
         if (!group || group->profiles().count() < 2) {
             _ui->profileNameEdit->setText(profile->name());
-            _ui->profileNameEdit->setClearButtonShown(true);
+            _ui->profileNameEdit->setClearButtonEnabled(true);
 
             _ui->emptyNameWarningWidget->setVisible(profile->name().isEmpty());
             _ui->emptyNameWarningWidget->setText(i18n("Profile name is empty."));
@@ -259,19 +272,38 @@ void EditProfileDialog::setupGeneralPage(const Profile::Ptr profile)
 
     ShellCommand command(profile->command() , profile->arguments());
     _ui->commandEdit->setText(command.fullCommand());
-    KUrlCompletion* exeCompletion = new KUrlCompletion(KUrlCompletion::ExeCompletion);
-    exeCompletion->setParent(this);
-    exeCompletion->setDir(QString());
-    _ui->commandEdit->setCompletionObject(exeCompletion);
 
+#pragma message("Look at this setCompletionObject again")
+//    KUrlCompletion* exeCompletion = new KUrlCompletion(KUrlCompletion::ExeCompletion);
+//    exeCompletion->setParent(this);
+//    exeCompletion->setDir(QUrl());
+//    _ui->commandEdit->setCompletionObject(exeCompletion);
+
+/* The below causes a noticeable delay when opening the dialog - I'm not entirely sure
+   this is the best way to handle this.
+   Issue is that QLineEdit->SetCompleter() won't work w/ KDE's KUrlCompletion
+
+    QFileSystemModel *commandEditDirModel = new QFileSystemModel(this);
+    commandEditDirModel->setFilter(QDir::AllEntries);
+    QFileInfo commandFileInfo(profile->command());
+    // If command is /usr/bin/zsh, start at /usr/bin for completion
+    commandEditDirModel->setRootPath(commandFileInfo.absolutePath());
+    QCompleter *commandEditCompleter = new QCompleter(this);
+    commandEditCompleter->setModel(commandEditDirModel);
+    _ui->commandEdit->setCompleter(commandEditCompleter);
+
+    QFileSystemModel *initialEditDirModel = new QFileSystemModel(this);
+    initialEditDirModel->setFilter(QDir::AllEntries);
+    initialEditDirModel->setRootPath(QString('/'));
     _ui->initialDirEdit->setText(profile->defaultWorkingDirectory());
-    KUrlCompletion* dirCompletion = new KUrlCompletion(KUrlCompletion::DirCompletion);
-    dirCompletion->setParent(this);
-    _ui->initialDirEdit->setCompletionObject(dirCompletion);
-    _ui->initialDirEdit->setClearButtonShown(true);
+    QCompleter *initialDirCompleter = new QCompleter(this);
+    initialDirCompleter->setModel(initialEditDirModel);
+    _ui->initialDirEdit->setCompleter(initialDirCompleter);
+*/
+    _ui->initialDirEdit->setClearButtonEnabled(true);
 
-    _ui->dirSelectButton->setIcon(KIcon("folder-open"));
-    _ui->iconSelectButton->setIcon(KIcon(profile->icon()));
+    _ui->dirSelectButton->setIcon(QIcon::fromTheme(QStringLiteral("folder-open")));
+    _ui->iconSelectButton->setIcon(QIcon::fromTheme(profile->icon()));
     _ui->startInSameDirButton->setChecked(profile->startInCurrentSessionDir());
 
     // terminal options
@@ -282,26 +314,18 @@ void EditProfileDialog::setupGeneralPage(const Profile::Ptr profile)
     _ui->showTerminalSizeHintButton->setChecked(profile->showTerminalSizeHint());
 
     // signals and slots
-    connect(_ui->dirSelectButton, SIGNAL(clicked()), this, SLOT(selectInitialDir()));
-    connect(_ui->iconSelectButton, SIGNAL(clicked()), this, SLOT(selectIcon()));
-    connect(_ui->startInSameDirButton, SIGNAL(toggled(bool)), this ,
-            SLOT(startInSameDir(bool)));
-    connect(_ui->profileNameEdit, SIGNAL(textChanged(QString)), this,
-            SLOT(profileNameChanged(QString)));
-    connect(_ui->initialDirEdit, SIGNAL(textChanged(QString)), this,
-            SLOT(initialDirChanged(QString)));
-    connect(_ui->commandEdit, SIGNAL(textChanged(QString)), this,
-            SLOT(commandChanged(QString)));
-    connect(_ui->environmentEditButton , SIGNAL(clicked()), this,
-            SLOT(showEnvironmentEditor()));
+    connect(_ui->dirSelectButton, &QToolButton::clicked, this, &Konsole::EditProfileDialog::selectInitialDir);
+    connect(_ui->iconSelectButton, &QPushButton::clicked, this, &Konsole::EditProfileDialog::selectIcon);
+    connect(_ui->startInSameDirButton, &QCheckBox::toggled, this , &Konsole::EditProfileDialog::startInSameDir);
+    connect(_ui->profileNameEdit, &QLineEdit::textChanged, this, &Konsole::EditProfileDialog::profileNameChanged);
+    connect(_ui->initialDirEdit, &QLineEdit::textChanged, this, &Konsole::EditProfileDialog::initialDirChanged);
+    connect(_ui->commandEdit, &QLineEdit::textChanged, this, &Konsole::EditProfileDialog::commandChanged);
+    connect(_ui->environmentEditButton , &QPushButton::clicked, this, &Konsole::EditProfileDialog::showEnvironmentEditor);
 
-    connect(_ui->terminalColumnsEntry, SIGNAL(valueChanged(int)),
-            this, SLOT(terminalColumnsEntryChanged(int)));
-    connect(_ui->terminalRowsEntry, SIGNAL(valueChanged(int)),
-            this, SLOT(terminalRowsEntryChanged(int)));
+    connect(_ui->terminalColumnsEntry, static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &Konsole::EditProfileDialog::terminalColumnsEntryChanged);
+    connect(_ui->terminalRowsEntry, static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &Konsole::EditProfileDialog::terminalRowsEntryChanged);
 
-    connect(_ui->showTerminalSizeHintButton, SIGNAL(toggled(bool)), this,
-            SLOT(showTerminalSizeHint(bool)));
+    connect(_ui->showTerminalSizeHintButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::showTerminalSizeHint);
 }
 void EditProfileDialog::showEnvironmentEditor()
 {
@@ -331,18 +355,15 @@ void EditProfileDialog::setupTabsPage(const Profile::Ptr profile)
     _ui->renameTabWidget->setTabTitleText(profile->localTabTitleFormat());
     _ui->renameTabWidget->setRemoteTabTitleText(profile->remoteTabTitleFormat());
 
-    connect(_ui->renameTabWidget, SIGNAL(tabTitleFormatChanged(QString)), this,
-            SLOT(tabTitleFormatChanged(QString)));
-    connect(_ui->renameTabWidget, SIGNAL(remoteTabTitleFormatChanged(QString)), this,
-            SLOT(remoteTabTitleFormatChanged(QString)));
+    connect(_ui->renameTabWidget, &Konsole::RenameTabWidget::tabTitleFormatChanged, this, &Konsole::EditProfileDialog::tabTitleFormatChanged);
+    connect(_ui->renameTabWidget, &Konsole::RenameTabWidget::remoteTabTitleFormatChanged, this, &Konsole::EditProfileDialog::remoteTabTitleFormatChanged);
 
     // tab monitoring
     const int silenceSeconds = profile->silenceSeconds();
     _ui->silenceSecondsSpinner->setValue(silenceSeconds);
     _ui->silenceSecondsSpinner->setSuffix(ki18ncp("Unit of time", " second", " seconds"));
 
-    connect(_ui->silenceSecondsSpinner, SIGNAL(valueChanged(int)),
-            this, SLOT(silenceSecondsChanged(int)));
+    connect(_ui->silenceSecondsSpinner, static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &Konsole::EditProfileDialog::silenceSecondsChanged);
 }
 
 void EditProfileDialog::terminalColumnsEntryChanged(int value)
@@ -376,7 +397,7 @@ void EditProfileDialog::selectIcon()
     const QString& icon = KIconDialog::getIcon(KIconLoader::Desktop, KIconLoader::Application,
                           false, 0, false, this);
     if (!icon.isEmpty()) {
-        _ui->iconSelectButton->setIcon(KIcon(icon));
+        _ui->iconSelectButton->setIcon(QIcon::fromTheme(icon));
         updateTempProfileProperty(Profile::Icon, icon);
     }
 }
@@ -405,7 +426,7 @@ void EditProfileDialog::commandChanged(const QString& command)
 }
 void EditProfileDialog::selectInitialDir()
 {
-    const KUrl url = KFileDialog::getExistingDirectoryUrl(_ui->initialDirEdit->text(),
+    const QUrl url = KFileDialog::getExistingDirectoryUrl(QUrl::fromUserInput(_ui->initialDirEdit->text()),
                      this,
                      i18n("Select Initial Directory"));
 
@@ -432,20 +453,14 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr profile)
     _ui->colorSchemeList->installEventFilter(this);
     _ui->colorSchemeList->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 
-    connect(_ui->colorSchemeList->selectionModel(),
-            SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(colorSchemeSelected()));
-    connect(_ui->colorSchemeList, SIGNAL(entered(QModelIndex)), this,
-            SLOT(previewColorScheme(QModelIndex)));
+    connect(_ui->colorSchemeList->selectionModel(), &QItemSelectionModel::selectionChanged, this, &Konsole::EditProfileDialog::colorSchemeSelected);
+    connect(_ui->colorSchemeList, &QListView::entered, this, &Konsole::EditProfileDialog::previewColorScheme);
 
     updateColorSchemeButtons();
 
-    connect(_ui->editColorSchemeButton, SIGNAL(clicked()), this,
-            SLOT(editColorScheme()));
-    connect(_ui->removeColorSchemeButton, SIGNAL(clicked()), this,
-            SLOT(removeColorScheme()));
-    connect(_ui->newColorSchemeButton, SIGNAL(clicked()), this,
-            SLOT(newColorScheme()));
+    connect(_ui->editColorSchemeButton, &QPushButton::clicked, this, &Konsole::EditProfileDialog::editColorScheme);
+    connect(_ui->removeColorSchemeButton, &QPushButton::clicked, this, &Konsole::EditProfileDialog::removeColorScheme);
+    connect(_ui->newColorSchemeButton, &QPushButton::clicked, this, &Konsole::EditProfileDialog::newColorScheme);
 
     // setup font preview
     const bool antialias = profile->antiAliasFonts();
@@ -457,22 +472,17 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr profile)
     _ui->fontPreviewLabel->setFont(profileFont);
     setFontInputValue(profileFont);
 
-    connect(_ui->fontSizeInput, SIGNAL(valueChanged(double)), this,
-            SLOT(setFontSize(double)));
-    connect(_ui->selectFontButton, SIGNAL(clicked()), this,
-            SLOT(showFontDialog()));
+    connect(_ui->fontSizeInput, SIGNAL(valueChanged(double)), this, SLOT(setFontSize(double)));
+    connect(_ui->selectFontButton, &QPushButton::clicked, this, &Konsole::EditProfileDialog::showFontDialog);
 
     // setup font smoothing
     _ui->antialiasTextButton->setChecked(antialias);
-    connect(_ui->antialiasTextButton, SIGNAL(toggled(bool)), this,
-            SLOT(setAntialiasText(bool)));
+    connect(_ui->antialiasTextButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::setAntialiasText);
 
     _ui->boldIntenseButton->setChecked(profile->boldIntense());
-    connect(_ui->boldIntenseButton, SIGNAL(toggled(bool)), this,
-            SLOT(setBoldIntense(bool)));
+    connect(_ui->boldIntenseButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::setBoldIntense);
     _ui->enableMouseWheelZoomButton->setChecked(profile->mouseWheelZoomEnabled());
-    connect(_ui->enableMouseWheelZoomButton, SIGNAL(toggled(bool)), this,
-            SLOT(toggleMouseWheelZoom(bool)));
+    connect(_ui->enableMouseWheelZoomButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::toggleMouseWheelZoom);
 }
 void EditProfileDialog::setAntialiasText(bool enable)
 {
@@ -553,11 +563,12 @@ void EditProfileDialog::updateKeyBindingsList(bool selectCurrentTranslator)
     QStringList translatorNames = keyManager->allTranslators();
     foreach(const QString& translatorName, translatorNames) {
         const KeyboardTranslator* translator = keyManager->findTranslator(translatorName);
+        if (!translator) continue;
 
         QStandardItem* item = new QStandardItem(translator->description());
         item->setEditable(false);
         item->setData(QVariant::fromValue(translator), Qt::UserRole + 1);
-        item->setIcon(KIcon("preferences-desktop-keyboard"));
+        item->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-keyboard")));
 
         if (translator == currentTranslator)
             selectedItem = item;
@@ -585,7 +596,7 @@ bool EditProfileDialog::eventFilter(QObject* watched , QEvent* aEvent)
         _ui->fontPreviewLabel->setText(i18n("%1", labelFont.family()));
     }
 
-    return KDialog::eventFilter(watched, aEvent);
+    return QDialog::eventFilter(watched, aEvent);
 }
 void EditProfileDialog::unpreviewAll()
 {
@@ -695,8 +706,7 @@ void EditProfileDialog::showColorSchemeEditor(bool isNewScheme)
     }
     _colorDialog = new ColorSchemeEditor(this);
 
-    connect(_colorDialog, SIGNAL(colorSchemeSaveRequested(ColorScheme,bool)),
-            this, SLOT(saveColorScheme(ColorScheme,bool)));
+    connect(_colorDialog, &Konsole::ColorSchemeEditor::colorSchemeSaveRequested, this, &Konsole::EditProfileDialog::saveColorScheme);
     _colorDialog->setup(colors, isNewScheme);
 
     _colorDialog->show();
@@ -819,7 +829,7 @@ void EditProfileDialog::updateButtonApply()
         }
     }
 
-    enableButtonApply(userModified);
+    mButtonBox->button(QDialogButtonBox::Apply)->setEnabled(userModified);
 }
 
 void EditProfileDialog::setupKeyboardPage(const Profile::Ptr /* profile */)
@@ -827,18 +837,13 @@ void EditProfileDialog::setupKeyboardPage(const Profile::Ptr /* profile */)
     // setup translator list
     updateKeyBindingsList(true);
 
-    connect(_ui->keyBindingList->selectionModel(),
-            SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            SLOT(keyBindingSelected()));
-    connect(_ui->newKeyBindingsButton, SIGNAL(clicked()), this,
-            SLOT(newKeyBinding()));
+    connect(_ui->keyBindingList->selectionModel(), &QItemSelectionModel::selectionChanged, this, &Konsole::EditProfileDialog::keyBindingSelected);
+    connect(_ui->newKeyBindingsButton, &QPushButton::clicked, this, &Konsole::EditProfileDialog::newKeyBinding);
 
     updateKeyBindingsButtons();
 
-    connect(_ui->editKeyBindingsButton, SIGNAL(clicked()), this,
-            SLOT(editKeyBinding()));
-    connect(_ui->removeKeyBindingsButton, SIGNAL(clicked()), this,
-            SLOT(removeKeyBinding()));
+    connect(_ui->editKeyBindingsButton, &QPushButton::clicked, this, &Konsole::EditProfileDialog::editKeyBinding);
+    connect(_ui->removeKeyBindingsButton, &QPushButton::clicked, this, &Konsole::EditProfileDialog::removeKeyBinding);
 }
 void EditProfileDialog::keyBindingSelected()
 {
@@ -881,9 +886,9 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
     QWeakPointer<KDialog> dialog = new KDialog(this);
 
     if (isNewTranslator)
-        dialog.data()->setCaption(i18n("New Key Binding List"));
+        dialog.data()->setWindowTitle(i18n("New Key Binding List"));
     else
-        dialog.data()->setCaption(i18n("Edit Key Binding List"));
+        dialog.data()->setWindowTitle(i18n("Edit Key Binding List"));
 
     KeyBindingEditor* editor = new KeyBindingEditor;
     dialog.data()->setMainWidget(editor);
@@ -960,8 +965,7 @@ void EditProfileDialog::setupScrollingPage(const Profile::Ptr profile)
     // setup scrollback type radio
     int scrollBackType = profile->property<int>(Profile::HistoryMode);
     _ui->historySizeWidget->setMode(Enum::HistoryModeEnum(scrollBackType));
-    connect(_ui->historySizeWidget, SIGNAL(historyModeChanged(Enum::HistoryModeEnum)),
-            this, SLOT(historyModeChanged(Enum::HistoryModeEnum)));
+    connect(_ui->historySizeWidget, &Konsole::HistorySizeWidget::historyModeChanged, this, &Konsole::EditProfileDialog::historyModeChanged);
 
     // setup scrollback line count spinner
     const int historySize = profile->historySize();
@@ -979,8 +983,7 @@ void EditProfileDialog::setupScrollingPage(const Profile::Ptr profile)
     setupRadio(pageamounts, scrollFullPage);
 
     // signals and slots
-    connect(_ui->historySizeWidget, SIGNAL(historySizeChanged(int)),
-            this, SLOT(historySizeChanged(int)));
+    connect(_ui->historySizeWidget, &Konsole::HistorySizeWidget::historySizeChanged, this, &Konsole::EditProfileDialog::historySizeChanged);
 }
 
 void EditProfileDialog::historySizeChanged(int lineCount)
@@ -1049,20 +1052,17 @@ void EditProfileDialog::setupMousePage(const Profile::Ptr profile)
     // interaction options
     _ui->wordCharacterEdit->setText(profile->wordCharacters());
 
-    connect(_ui->wordCharacterEdit, SIGNAL(textChanged(QString)), this,
-            SLOT(wordCharactersChanged(QString)));
+    connect(_ui->wordCharacterEdit, &QLineEdit::textChanged, this, &Konsole::EditProfileDialog::wordCharactersChanged);
 
     int tripleClickMode = profile->property<int>(Profile::TripleClickMode);
     _ui->tripleClickModeCombo->setCurrentIndex(tripleClickMode);
 
-    connect(_ui->tripleClickModeCombo, SIGNAL(activated(int)), this,
-            SLOT(TripleClickModeChanged(int)));
+    connect(_ui->tripleClickModeCombo, static_cast<void(KComboBox::*)(int)>(&KComboBox::activated), this, &Konsole::EditProfileDialog::TripleClickModeChanged);
 
     _ui->openLinksByDirectClickButton->setEnabled(_ui->underlineLinksButton->isChecked());
 
     _ui->enableMouseWheelZoomButton->setChecked(profile->mouseWheelZoomEnabled());
-    connect(_ui->enableMouseWheelZoomButton, SIGNAL(toggled(bool)), this,
-            SLOT(toggleMouseWheelZoom(bool)));
+    connect(_ui->enableMouseWheelZoomButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::toggleMouseWheelZoom);
 }
 void EditProfileDialog::setupAdvancedPage(const Profile::Ptr profile)
 {
@@ -1089,8 +1089,7 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr profile)
     const int lineSpacing = profile->lineSpacing();
     _ui->lineSpacingSpinner->setValue(lineSpacing);
 
-    connect(_ui->lineSpacingSpinner, SIGNAL(valueChanged(int)),
-            this, SLOT(lineSpacingChanged(int)));
+    connect(_ui->lineSpacingSpinner, static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &Konsole::EditProfileDialog::lineSpacingChanged);
 
     // cursor options
     if (profile->useCustomCursorColor())
@@ -1100,20 +1099,19 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr profile)
 
     _ui->customColorSelectButton->setColor(profile->customCursorColor());
 
-    connect(_ui->customCursorColorButton, SIGNAL(clicked()), this, SLOT(customCursorColor()));
-    connect(_ui->autoCursorColorButton, SIGNAL(clicked()), this, SLOT(autoCursorColor()));
-    connect(_ui->customColorSelectButton, SIGNAL(changed(QColor)),
-            SLOT(customCursorColorChanged(QColor)));
+    connect(_ui->customCursorColorButton, &QRadioButton::clicked, this, &Konsole::EditProfileDialog::customCursorColor);
+    connect(_ui->autoCursorColorButton, &QRadioButton::clicked, this, &Konsole::EditProfileDialog::autoCursorColor);
+    connect(_ui->customColorSelectButton, &KColorButton::changed, this, &Konsole::EditProfileDialog::customCursorColorChanged);
 
     int shape = profile->property<int>(Profile::CursorShape);
     _ui->cursorShapeCombo->setCurrentIndex(shape);
 
-    connect(_ui->cursorShapeCombo, SIGNAL(activated(int)), this, SLOT(setCursorShape(int)));
+    connect(_ui->cursorShapeCombo, static_cast<void(KComboBox::*)(int)>(&KComboBox::activated), this, &Konsole::EditProfileDialog::setCursorShape);
 
     // encoding options
-    QAction* codecAction = new KCodecAction(this);
+    KCodecAction* codecAction = new KCodecAction(this);
     _ui->selectEncodingButton->setMenu(codecAction->menu());
-    connect(codecAction, SIGNAL(triggered(QTextCodec*)), this, SLOT(setDefaultCodec(QTextCodec*)));
+    connect(codecAction, static_cast<void(KCodecAction::*)(QTextCodec*)>(&KCodecAction::triggered), this, &Konsole::EditProfileDialog::setDefaultCodec);
 
     _ui->characterEncodingLabel->setText(profile->defaultEncoding());
 }
@@ -1222,7 +1220,7 @@ void EditProfileDialog::showFontDialog()
     QFont currentFont = _ui->fontPreviewLabel->font();
 
     QWeakPointer<KFontDialog> dialog = new KFontDialog(this, KFontChooser::FixedFontsOnly);
-    dialog.data()->setCaption(i18n("Select Fixed Width Font"));
+    dialog.data()->setWindowTitle(i18n("Select Fixed Width Font"));
     dialog.data()->setFont(currentFont, true);
 
     // TODO (hindenburg): When https://git.reviewboard.kde.org/r/103357 is
@@ -1232,7 +1230,7 @@ void EditProfileDialog::showFontDialog()
     if (!chooserList.isEmpty())
         chooserList.at(0)->setSampleText(sampleText);
 
-    connect(dialog.data(), SIGNAL(fontSelected(QFont)), this, SLOT(fontSelected(QFont)));
+    connect(dialog.data(), &KFontDialog::fontSelected, this, &Konsole::EditProfileDialog::fontSelected);
 
     if (dialog.data()->exec() == QDialog::Rejected)
         fontSelected(currentFont);
@@ -1319,22 +1317,17 @@ void ColorSchemeViewDelegate::paint(QPainter* painter, const QStyleOptionViewIte
     painter->setBrush(gradient);
     painter->drawRoundRect(backgroundRect , 4 , 30);
 
-    //const bool isChecked = index.data(Qt::CheckStateRole) == Qt::Checked;
     const bool isSelected = option.state & QStyle::State_Selected;
 
     // draw border on selected items
-    if (isSelected) { //|| isChecked )
+    if (isSelected) {
         static const int selectedBorderWidth = 6;
 
         painter->setBrush(QBrush(Qt::NoBrush));
         QPen pen;
 
         QColor highlightColor = option.palette.highlight().color();
-
-        if (isSelected)
-            highlightColor.setAlphaF(1.0);
-        else
-            highlightColor.setAlphaF(0.7);
+        highlightColor.setAlphaF(1.0);
 
         pen.setBrush(highlightColor);
         pen.setWidth(selectedBorderWidth);
@@ -1368,4 +1361,3 @@ QSize ColorSchemeViewDelegate::sizeHint(const QStyleOptionViewItem& option,
     return QSize(width, static_cast<int>(heightForWidth));
 }
 
-#include "EditProfileDialog.moc"
