@@ -24,18 +24,34 @@
 // Konsole
 #include "ui_HistorySizeDialog.h"
 
+#include <KLocalizedString>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
+
 using namespace Konsole;
 
 HistorySizeDialog::HistorySizeDialog(QWidget* parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    setCaption(i18nc("@title:window", "Adjust Scrollback"));
-    setButtons(KDialog::Ok | KDialog::Cancel);
+    setWindowTitle(i18nc("@title:window", "Adjust Scrollback"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &HistorySizeDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &HistorySizeDialog::reject);
+    mainLayout->addWidget(buttonBox);
 
     setWindowModality(Qt::WindowModal);
 
     _ui = new Ui::HistorySizeDialog();
-    _ui->setupUi(mainWidget());
+    _ui->setupUi(mainWidget);
 
     _ui->tempWarningWidget->setVisible(true);
     _ui->tempWarningWidget->setWordWrap(true);
@@ -70,4 +86,3 @@ void HistorySizeDialog::setLineCount(int lines)
     _ui->historySizeWidget->setLineCount(lines);
 }
 
-#include "HistorySizeDialog.moc"
