@@ -25,11 +25,12 @@
 // Qt
 #include <QtCore/QHash>
 #include <QtCore/QList>
+#include <QtCore/QString>
 //#include <QtGui/QKeySequence>
 #include <QtCore/QMetaType>
 
 // Konsole
-#include "konsole_export.h"
+#include "konsoleprivate_export.h"
 
 class QIODevice;
 class QTextStream;
