@@ -26,8 +26,8 @@
 #include <QtCore/QTextCodec>
 
 // KDE
-#include <KGlobalSettings>
 #include <KLocalizedString>
+#include <QFontDatabase>
 
 // Konsole
 #include "Enumeration.h"
@@ -163,7 +163,7 @@ FallbackProfile::FallbackProfile()
 
     setProperty(KeyBindings, "default");
     setProperty(ColorScheme, "Linux"); //use DarkPastels when is start support blue ncurses UI properly
-    setProperty(Font, KGlobalSettings::fixedFont());
+    setProperty(Font, QFontDatabase::systemFont(QFontDatabase::FixedFont));
 
     setProperty(HistoryMode, Enum::FixedSizeHistory);
     setProperty(HistorySize, 1000);
@@ -187,7 +187,7 @@ FallbackProfile::FallbackProfile()
     setProperty(LineSpacing, 0);
     setProperty(CursorShape, Enum::BlockCursor);
     setProperty(UseCustomCursorColor, false);
-    setProperty(CustomCursorColor, Qt::black);
+    setProperty(CustomCursorColor, QColor(Qt::black));
     setProperty(BellMode, Enum::NotifyBell);
 
     setProperty(DefaultEncoding, QString(QTextCodec::codecForLocale()->name()));
