@@ -30,10 +30,8 @@
 
 // KDE
 #include <KConfig>
-#include <KGlobal>
-#include <KDebug>
+#include <QDebug>
 #include <KConfigGroup>
-#include <KStandardDirs>
 
 // Konsole
 #include "ProfileReader.h"
@@ -77,7 +75,7 @@ ProfileManager::ProfileManager()
     // lookup the default profile specified in <App>rc
     // for stand-alone Konsole, appConfig is just konsolerc
     // for konsolepart, appConfig might be yakuakerc, dolphinrc, katerc...
-    KSharedConfigPtr appConfig = KGlobal::config();
+    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup group = appConfig->group("Desktop Entry");
     QString defaultProfileFileName = group.readEntry("DefaultProfile", "");
 
@@ -90,7 +88,8 @@ ProfileManager::ProfileManager()
     }
 
     // load the default profile
-    const QString path = KStandardDirs::locate("data", "konsole/" + defaultProfileFileName);
+    const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + defaultProfileFileName);
+
     if (!path.isEmpty()) {
         Profile::Ptr profile = loadProfile(path);
         if (profile)
@@ -110,7 +109,7 @@ ProfileManager::~ProfileManager()
 {
 }
 
-K_GLOBAL_STATIC(ProfileManager , theProfileManager)
+Q_GLOBAL_STATIC(ProfileManager, theProfileManager)
 ProfileManager* ProfileManager::instance()
 {
     return theProfileManager;
@@ -137,7 +136,7 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
 
     // if the file is not an absolute path, look it up
     if (!fileInfo.isAbsolute())
-        path = KStandardDirs::locate("data", path);
+        path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, path);
 
     // if the file is not found, return immediately
     if (path.isEmpty()) {
@@ -157,7 +156,7 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
     PopStackOnExit<QString> popGuardOnExit(recursionGuard);
 
     if (recursionGuard.contains(path)) {
-        kWarning() << "Ignoring attempt to load profile recursively from" << path;
+        qWarning() << "Ignoring attempt to load profile recursively from" << path;
         return _fallbackProfile;
     } else {
         recursionGuard.push(path);
@@ -180,7 +179,7 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
     delete reader;
 
     if (!result) {
-        kWarning() << "Could not load profile from " << path;
+        qWarning() << "Could not load profile from " << path;
         return Profile::Ptr();
     } else {
         addProfile(newProfile);
@@ -281,7 +280,7 @@ void ProfileManager::saveSettings()
     saveFavorites();
 
     // ensure default/favorites/shortcuts settings are synced into disk
-    KSharedConfigPtr appConfig = KGlobal::config();
+    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     appConfig->sync();
 }
 
@@ -384,7 +383,7 @@ bool ProfileManager::deleteProfile(Profile::Ptr profile)
         // try to delete the config file
         if (profile->isPropertySet(Profile::Path) && QFile::exists(profile->path())) {
             if (!QFile::remove(profile->path())) {
-                kWarning() << "Could not delete profile: " << profile->path()
+                qWarning() << "Could not delete profile: " << profile->path()
                            << "The file is most likely in a directory which is read-only.";
 
                 return false;
@@ -428,7 +427,7 @@ void ProfileManager::saveDefaultProfile()
 
     QFileInfo fileInfo(path);
 
-    KSharedConfigPtr appConfig = KGlobal::config();
+    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup group = appConfig->group("Desktop Entry");
     group.writeEntry("DefaultProfile", fileInfo.fileName());
 }
@@ -454,7 +453,7 @@ void ProfileManager::setFavorite(Profile::Ptr profile , bool favorite)
 }
 void ProfileManager::loadShortcuts()
 {
-    KSharedConfigPtr appConfig = KGlobal::config();
+    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup shortcutGroup = appConfig->group("Profile Shortcuts");
 
     QMap<QString, QString> entries = shortcutGroup.entryMap();
@@ -471,7 +470,7 @@ void ProfileManager::loadShortcuts()
         // if the file is not an absolute path, look it up
         QFileInfo fileInfo(profilePath);
         if (!fileInfo.isAbsolute()) {
-            profilePath = KStandardDirs::locate("data", "konsole/" + profilePath);
+            profilePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + profilePath);
         }
 
         data.profilePath = profilePath;
@@ -480,7 +479,7 @@ void ProfileManager::loadShortcuts()
 }
 void ProfileManager::saveShortcuts()
 {
-    KSharedConfigPtr appConfig = KGlobal::config();
+    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup shortcutGroup = appConfig->group("Profile Shortcuts");
     shortcutGroup.deleteGroup();
 
@@ -497,8 +496,8 @@ void ProfileManager::saveShortcuts()
         if (fileInfo.isAbsolute()) {
             // Check to see if file is under KDE's data locations.  If not,
             // store full path.
-            QString location = KGlobal::dirs()->locate("data",
-                               "konsole/" + fileInfo.fileName());
+            const QString location = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                            QStringLiteral("konsole/") + fileInfo.fileName());
             if (location.isEmpty()) {
                 profileName = iter.value().profilePath;
             } else  {
@@ -534,7 +533,7 @@ void ProfileManager::loadFavorites()
     if (_loadedFavorites)
         return;
 
-    KSharedConfigPtr appConfig = KGlobal::config();
+    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup favoriteGroup = appConfig->group("Favorite Profiles");
 
     QSet<QString> favoriteSet;
@@ -567,7 +566,7 @@ void ProfileManager::loadFavorites()
 }
 void ProfileManager::saveFavorites()
 {
-    KSharedConfigPtr appConfig = KGlobal::config();
+    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup favoriteGroup = appConfig->group("Favorite Profiles");
 
     QStringList paths;
@@ -580,8 +579,8 @@ void ProfileManager::saveFavorites()
         if (fileInfo.isAbsolute()) {
             // Check to see if file is under KDE's data locations.  If not,
             // store full path.
-            QString location = KGlobal::dirs()->locate("data",
-                               "konsole/" + fileInfo.fileName());
+            const QString location = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + fileInfo.fileName());
+
             if (location.isEmpty()) {
                 profileName = profile->path();
             } else {
@@ -632,5 +631,3 @@ QKeySequence ProfileManager::shortcut(Profile::Ptr profile) const
     return QKeySequence();
 }
 
-#include "ProfileManager.moc"
-
